==> flutter_feedback-1.1.6.tar.gz: lib/localization/en_message.dart <==
import 'package:flutter_feedback/localization/lookup_message.dart';

class EnMessage implements LookupMessage {
  @override
  String appreciation() {
    return 'Appreciation';
  }

  @override
  String complain() {
    return 'Complain';
  }

  @override
  String delete() {
    return 'Delete';
  }

  @override
  String deleteScreenshot() {
    return 'Delete screenshot';
  }

  @override
  String edit() {
    return 'Edit';
  }

  @override
  String editScreenshot() {
    return 'Edit screenshot';
  }

  @override
  String enterYourFeedback() {
    return 'Enter your feedback';
  }

  @override
  String feedback() {
    return 'Feedback';
  }

  @override
  String info() {
    return 'Info';
  }

  @override
  String loading() {
    return 'Loading';
  }

  @override
  String login() {
    return 'Login';
  }

  @override
  String ok() {
    return 'Ok';
  }

  @override
  String pleaseLeaveYourFeedback() {
    return 'Please leave your feedback below';
  }

  @override
  String pleaseSelectFeedbackCategory() {
    return 'Please select feedback category';
  }

  @override
  String pleaseSelectYourFeedbackCategoryBelow() {
    return 'Please select your feedback category below';
  }

  @override
  String refreshTokenExpired() {
    return 'Your session has expired. Please log in again';
  }

  @override
  String screenshots() {
    return 'Screenshots';
  }

  @override
  String send() {
    return 'Send';
  }

  @override
  String suggestion() {
    return 'Suggestion';
  }

  @override
  String thankYouForTheFeedback() {
    return 'Thank you for the feedback';
  }

  @override
  String weWouldLikeYourFeedback() {
    return 'We would like your feedback to improve our app';
  }

  @override
  String whatIsYourOpinionOfThisPage() {
    return 'What is your opinion of this page?';
  }

  @override
  String typeMessageHere() {
    return 'Type message here';
  }
}

==> flutter_feedback-2.2.0.tar.gz: lib/localization/en_message.dart <==
import 'package:flutter_feedback/localization/lookup_message.dart';

class EnMessage implements LookupMessage {
  @override
  String appreciation() {
    return 'Appreciation';
  }

  @override
  String complain() {
    return 'Complain';
  }

  @override
  String delete() {
    return 'Delete';
  }

  @override
  String deleteScreenshot() {
    return 'Delete Screenshot';
  }

  @override
  String edit() {
    return 'Edit';
  }

  @override
  String editScreenshot() {
    return 'Edit Screenshot';
  }

  @override
  String enterYourFeedback() {
    return 'Enter your feedback';
  }

  @override
  String feedback() {
    return 'Feedback';
  }

  @override
  String info() {
    return 'Info';
  }

  @override
  String loading() {
    return 'Loading';
  }

  @override
  String login() {
    return 'Login';
  }

  @override
  String ok() {
    return 'Ok';
  }

  @override
  String pleaseLeaveYourFeedback() {
    return 'Please leave your feedback below';
  }

  @override
  String pleaseSelectFeedbackCategory() {
    return 'Please select feedback category';
  }

  @override
  String pleaseSelectYourFeedbackCategoryBelow() {
    return 'Please select your feedback category below';
  }

  @override
  String refreshTokenExpired() {
    return 'Your session has expired. Please log in again';
  }

  @override
  String screenshots() {
    return 'Screenshots';
  }

  @override
  String send() {
    return 'Send';
  }

  @override
  String suggestion() {
    return 'Suggestion';
  }

  @override
  String thankYouForTheFeedback() {
    return 'Thank you for the feedback';
  }

  @override
  String weWouldLikeYourFeedback() {
    return 'We would like your feedback to improve our app';
  }

  @override
  String whatIsYourOpinionOfThisPage() {
    return 'What is your opinion of this images?';
  }

  @override
  String typeMessageHere() {
    return 'Type message here';
  }

  @override
  String viewScreenshot() {
    return 'View Screenshot';
  }

  @override
  String pleaseUploadScreenshot() {
    return 'Please provide at least one image to support your feedback';
  }
}
